@@ -1,23 +1,33 @@
 from abc import abstractmethod
 import ast
-from typing import List
-from turms.config import GeneratorConfig
+from optparse import Option
+from typing import List, Optional
+
+from pydantic import BaseModel, BaseSettings
 from graphql.utilities.build_client_schema import GraphQLSchema
-from turms.registry import ClassRegistry
 
 
-class Plugin:
+class PluginConfig(BaseSettings):
+    type: str
+
+    class Config:
+        extra = "forbid"
+
+
+class Plugin(BaseModel):
     """Base Plugin Class
 
     Raises:
         NotImplementedError: [description]
     """
 
+    config: PluginConfig
+
     @abstractmethod
-    def generate_tree(
+    def generate_ast(
         self,
-        config: GeneratorConfig,
+        config,
         client_schema: GraphQLSchema,
-        registry: ClassRegistry,
+        registry,
     ) -> List[ast.AST]:
         raise NotImplementedError("Plugin must overrwrite this")
