@@ -1,31 +1,38 @@
-from turms.globals import ENUM_CLASS_MAP
-from turms.plugins.base import Plugin
+from turms.plugins.base import Plugin, PluginConfig
 from abc import abstractmethod
 import ast
 from typing import List, Optional
 from turms.config import GeneratorConfig
 from graphql.utilities.build_client_schema import GraphQLSchema
 from turms.plugins.base import Plugin
-from pydantic import BaseModel
+from pydantic import BaseModel, BaseSettings, Field
 from graphql.type.definition import (
     GraphQLEnumType,
 )
 import keyword
 
+from turms.registry import ClassRegistry
+
 
 class EnumsPluginsError(Exception):
     pass
 
-class EnumsPluginConfig(BaseModel):
+
+class EnumsPluginConfig(PluginConfig):
+    type = "turms.plugins.enums.EnumsPlugin"
     skip_underscore: bool = True
     prepend: str = ""
     append: str = ""
 
+    class Config:
+        env_prefix = "TURMS_PLUGINS_ENUMS_"
+
 
 def generate_enums(
     client_schema: GraphQLSchema,
     config: GeneratorConfig,
     plugin_config: EnumsPluginConfig,
+    registry: ClassRegistry,
 ):
 
     tree = []
@@ -41,14 +48,18 @@ def generate_enums(
         if plugin_config.skip_underscore and key.startswith("_"):
             continue
 
-        name = f"{config.prepend_enum}{key}{config.append_enum}"
-        fields = [ast.Expr(value=ast.Constant(value=type.description))] if type.description else []
+        name = registry.generate_enum_classname(key)
+        fields = (
+            [ast.Expr(value=ast.Constant(value=type.description))]
+            if type.description
+            else []
+        )
 
         for value_key, value in type.values.items():
+
             if keyword.iskeyword(value_key):
                 value_key = f"{value_key}_"
 
-
             assign = ast.Assign(
                 targets=[ast.Name(id=str(value_key), ctx=ast.Store())],
                 value=ast.Constant(value=value.value),
@@ -69,7 +80,7 @@ def generate_enums(
             else:
                 fields += [assign]
 
-        ENUM_CLASS_MAP[key] = name
+        registry.register_enum_class(key, name)
         tree.append(
             ast.ClassDef(
                 name,
@@ -87,26 +98,15 @@ def generate_enums(
 
 
 class EnumsPlugin(Plugin):
-    def __init__(self, config=None, **data):
-        self.plugin_config = config or EnumsPluginConfig(**data)
+    config: EnumsPluginConfig = Field(default_factory=EnumsPluginConfig)
 
-    def generate_imports(
-        self, config: GeneratorConfig, client_schema: GraphQLSchema
-    ) -> List[ast.AST]:
-        imports = []
-
-        imports.append(
-            ast.ImportFrom(
-                module="enum",
-                names=[ast.alias(name="Enum")],
-                level=0,
-            )
-        )
-
-        return imports
-
-    def generate_body(
-        self, client_schema: GraphQLSchema, config: GeneratorConfig
+    def generate_ast(
+        self,
+        client_schema: GraphQLSchema,
+        config: GeneratorConfig,
+        registry: ClassRegistry,
     ) -> List[ast.AST]:
 
-        return generate_enums(client_schema, config, self.plugin_config)
+        registry.register_import("enum.Enum")
+
+        return generate_enums(client_schema, config, self.config, registry)
