@@ -3,15 +3,17 @@ import ast
 from typing import Callable, List, Optional
 from turms.config import GeneratorConfig
 from graphql.utilities.build_client_schema import GraphQLSchema
-from turms.parser.recurse import recurse_annotation, type_field_node
-from turms.plugins.base import Plugin
-from pydantic import BaseModel
+from turms.recurse import recurse_annotation, type_field_node
+from turms.plugins.base import Plugin, PluginConfig
+from pydantic import BaseModel, BaseSettings, Field
 from graphql.language.ast import FragmentDefinitionNode
 from turms.registry import ClassRegistry
 from turms.utils import (
     NoDocumentsFoundError,
+    generate_config_class,
     generate_typename_field,
     get_additional_bases_for_type,
+    get_interface_bases,
     parse_documents,
 )
 import re
@@ -34,10 +36,38 @@ import logging
 logger = logging.getLogger(__name__)
 
 
-class FragmentsPluginConfig(BaseModel):
-    fragment_bases: List[str] = ["turms.types.object.GraphQLObject"]
+class FragmentsPluginConfig(PluginConfig):
+    type = "turms.plugins.fragments.FragmentsPlugin"
+    fragment_bases: List[str] = None
     fragments_glob: Optional[str]
 
+    class Config:
+        env_prefix = "TURMS_PLUGINS_FRAGMENTS_"
+
+
+def get_fragment_bases(
+    config: GeneratorConfig,
+    pluginConfig: FragmentsPluginConfig,
+    registry: ClassRegistry,
+):
+    if pluginConfig.fragment_bases:
+        for base in pluginConfig.fragment_bases:
+            registry.register_import(base)
+
+        return [
+            ast.Name(id=base.split(".")[-1], ctx=ast.Load())
+            for base in pluginConfig.fragment_bases
+        ]
+
+    else:
+        for base in config.object_bases:
+            registry.register_import(base)
+
+        return [
+            ast.Name(id=base.split(".")[-1], ctx=ast.Load())
+            for base in config.object_bases
+        ]
+
 
 def generate_fragment(
     f: FragmentDefinitionNode,
@@ -49,7 +79,6 @@ def generate_fragment(
     tree = []
     fields = []
     type = client_schema.get_type(f.type_condition.name.value)
-
     name = registry.generate_fragment_classname(f.name.value)
 
     if isinstance(type, GraphQLInterfaceType):
@@ -61,24 +90,6 @@ def generate_fragment(
                 ast.Expr(value=ast.Constant(value=type.description))
             )
 
-        mother_class_fields += [
-            ast.AnnAssign(
-                target=ast.Name(id="typename", ctx=ast.Store()),
-                annotation=ast.Subscript(
-                    value=ast.Name(id="Optional", ctx=ast.Load()),
-                    slice=ast.Name("str", ctx=ast.Load()),
-                ),
-                value=ast.Call(
-                    func=ast.Name(id="Field", ctx=ast.Load()),
-                    args=[],
-                    keywords=[
-                        ast.keyword(arg="alias", value=ast.Constant(value="__typename"))
-                    ],
-                ),
-                simple=1,
-            )
-        ]
-
         for sub_node in f.selection_set.selections:
 
             if isinstance(sub_node, FieldNode):
@@ -101,10 +112,7 @@ def generate_fragment(
 
         mother_class = ast.ClassDef(
             base_fragment_name,
-            bases=[
-                ast.Name(id=base.split(".")[-1], ctx=ast.Load())
-                for base in config.interface_bases
-            ]
+            bases=get_interface_bases(config, registry)
             + additional_bases,  # Todo: fill with base
             decorator_list=[],
             keywords=[],
@@ -178,13 +186,14 @@ def generate_fragment(
                     ],
                     decorator_list=[],
                     keywords=[],
-                    body=inline_fragment_fields,
+                    body=inline_fragment_fields + generate_config_class(config),
                 )
 
                 tree.append(cls)
                 union_class_names.append(inline_name)
 
-        union_class_names.append(base_fragment_name)
+        if not config.always_resolve_interfaces:
+            union_class_names.append(base_fragment_name)
 
         registry.register_fragment_document(f.name.value, language.print_ast(f))
         registry.register_fragment_class(f.name.value, name)
@@ -219,6 +228,9 @@ def generate_fragment(
 
     for field in f.selection_set.selections:
 
+        if field.name.value == "__typename":
+            continue
+
         if isinstance(field, FragmentDefinitionNode):
             continue
 
@@ -228,12 +240,6 @@ def generate_fragment(
         field_definition = get_field_def(client_schema, type, field)
         assert field_definition, "Couldn't find field definition"
 
-        target = (
-            field.alias.value
-            if hasattr(field, "alias") and field.alias
-            else field.name.value
-        )
-
         fields += type_field_node(
             field,
             field_definition,
@@ -250,21 +256,17 @@ def generate_fragment(
         ast.ClassDef(
             name,
             bases=additional_bases
-            + [
-                ast.Name(id=base.split(".")[-1], ctx=ast.Load())
-                for base in plugin_config.fragment_bases
-            ],
+            + get_fragment_bases(config, plugin_config, registry),
             decorator_list=[],
             keywords=[],
-            body=fields,
+            body=fields + generate_config_class(config),
         )
     )
     return tree
 
 
 class FragmentsPlugin(Plugin):
-    def __init__(self, config=None, **data):
-        self.plugin_config = config or FragmentsPluginConfig(**data)
+    config: FragmentsPluginConfig = Field(default_factory=FragmentsPluginConfig)
 
     def generate_ast(
         self,
@@ -275,12 +277,9 @@ class FragmentsPlugin(Plugin):
 
         plugin_tree = []
 
-        for base in self.plugin_config.fragment_bases:
-            registry.register_import(base)
-
         try:
             documents = parse_documents(
-                client_schema, self.plugin_config.fragments_glob or config.documents
+                client_schema, self.config.fragments_glob or config.documents
             )
         except NoDocumentsFoundError as e:
             logger.exception(e)
@@ -294,7 +293,7 @@ class FragmentsPlugin(Plugin):
 
         for fragment in fragments:
             plugin_tree += generate_fragment(
-                fragment, client_schema, config, self.plugin_config, registry
+                fragment, client_schema, config, self.config, registry
             )
 
         return plugin_tree
