@@ -7,13 +7,13 @@ from graphql import (
     GraphQLScalarType,
     GraphQLWrappingType,
 )
-from turms.plugins.base import Plugin
+from turms.plugins.base import Plugin, PluginConfig
 import ast
 from typing import List, Optional
 from turms.config import GeneratorConfig
 from graphql.utilities.build_client_schema import GraphQLSchema
 from turms.plugins.base import Plugin
-from pydantic import BaseModel
+from pydantic import BaseModel, BaseSettings, Field
 from graphql.type.definition import (
     GraphQLEnumType,
 )
@@ -21,10 +21,14 @@ import keyword
 from turms.registry import ClassRegistry
 
 
-class InputsPluginConfig(BaseModel):
-    inputtype_bases: List[str] = ["turms.types.object.GraphQLInputObject"]
+class InputsPluginConfig(PluginConfig):
+    type = "turms.plugins.inputs.InputsPlugin"
+    inputtype_bases: List[str] = ["pydantic.BaseModel"]
     skip_underscore: bool = True
 
+    class Config:
+        env_prefix = "TURMS_PLUGINS_INPUTS_"
+
 
 def generate_input_annotation(
     type: GraphQLInputType,
@@ -118,6 +122,9 @@ def generate_inputs(
         if isinstance(value, GraphQLInputObjectType)
     }
 
+    for base in plugin_config.inputtype_bases:
+        registry.register_import(base)
+
     self_referential = set()
 
     for key, type in inputobjects_type.items():
@@ -140,6 +147,7 @@ def generate_inputs(
             field_name = registry.generate_node_name(value_key)
 
             if field_name != value_key:
+                registry.register_import("pydantic.Field")
                 assign = ast.AnnAssign(
                     target=ast.Name(field_name, ctx=ast.Store()),
                     annotation=generate_input_annotation(
@@ -181,6 +189,7 @@ def generate_inputs(
                 fields += [assign]
 
         registry.register_inputtype_class(key, name)
+
         tree.append(
             ast.ClassDef(
                 name,
@@ -216,8 +225,7 @@ def generate_inputs(
 
 
 class InputsPlugin(Plugin):
-    def __init__(self, config=None, **data):
-        self.plugin_config = config or InputsPluginConfig(**data)
+    config: InputsPluginConfig = Field(default_factory=InputsPluginConfig)
 
     def generate_ast(
         self,
@@ -226,7 +234,7 @@ class InputsPlugin(Plugin):
         registry: ClassRegistry,
     ) -> List[ast.AST]:
 
-        for base in self.plugin_config.inputtype_bases:
+        for base in self.config.inputtype_bases:
             registry.register_import(base)
 
-        return generate_inputs(client_schema, config, self.plugin_config, registry)
+        return generate_inputs(client_schema, config, self.config, registry)
