@@ -5,6 +5,8 @@ from turms.config import GeneratorConfig
 from keyword import iskeyword
 from turms.errors import NoScalarEquivalentFound
 from turms.stylers.base import Styler
+from rich import get_console
+
 
 SCALAR_DEFAULTS = {
     "ID": "str",
@@ -26,6 +28,7 @@ class ClassRegistry(object):
         self.enum_class_map = {}
         self.inputtype_class_map = {}
         self.fragment_class_map = {}
+        self.console = get_console()
 
     def generate_type_name_field(self, typename):
         return ast.AnnAssign(
@@ -62,6 +65,15 @@ class ClassRegistry(object):
 
         return node_name
 
+    def generate_parameter_name(self, node_name: str):
+        for styler in self.stylers:
+            node_name = styler.style_parameter_name(node_name)
+
+        if iskeyword(node_name):
+            return node_name + "_"
+
+        return node_name
+
     def generate_fragment_classname(self, typename: str):
         for styler in self.stylers:
             typename = styler.style_fragment_name(typename)
@@ -108,6 +120,9 @@ class ClassRegistry(object):
         return typename
 
     def register_import(self, name):
+        if name in ("bool", "str", "int", "float", "dict", "list", "tuple"):
+            return
+
         assert "." in name, "Please only register imports with a top level package"
         self._imports.add(name)
 
@@ -121,7 +136,6 @@ class ClassRegistry(object):
             )
 
         for top_level_name, sub_level_names in top_level.items():
-            print(top_level_name)
             imports.append(
                 ast.ImportFrom(
                     module=top_level_name,
@@ -190,3 +204,6 @@ class ClassRegistry(object):
             )
 
         return scalar_type.split(".")[-1]
+
+    def warn(self, message):
+        self.console.print("[r]" + message)
