@@ -1,7 +1,7 @@
 import glob
 import re
 from typing import Dict, List
-from turms.config import GeneratorConfig
+from turms.config import GeneratorConfig, GraphQLConfig
 from graphql.utilities.build_client_schema import GraphQLSchema
 from graphql.language.ast import DocumentNode, FieldNode
 from graphql.error.graphql_error import GraphQLError
@@ -62,6 +62,32 @@ def generate_typename_field(typename, registry: ClassRegistry):
     )
 
 
+def generate_config_class(config: GeneratorConfig):
+
+    config_fields = []
+
+    if config.freeze:
+        config_fields.append(
+            ast.Assign(
+                targets=[ast.Name(id="frozen", ctx=ast.Store())],
+                value=ast.Constant(value=True),
+            )
+        )
+
+    if len(config_fields) > 0:
+        return [
+            ast.ClassDef(
+                name="Config",
+                bases=[],
+                keywords=[],
+                body=config_fields,
+                decorator_list=[],
+            )
+        ]
+    else:
+        return []
+
+
 def parse_documents(
     client_schema: GraphQLSchema, scan_glob="g/*/**.graphql"
 ) -> DocumentNode:
@@ -99,7 +125,7 @@ def replace_iteratively(
     registry,
     taken=[],
 ):
-    z = fragment_searcher.findall(pattern)
+    z = set(fragment_searcher.findall(pattern))  # only set is important
     new_fragments = [new_f for new_f in z if new_f not in taken and new_f != ""]
     if not new_fragments:
         return pattern
@@ -131,3 +157,23 @@ def get_additional_bases_for_type(
             for base in config.additional_bases[typename]
         ]
     return []
+
+
+def get_interface_bases(config: GeneratorConfig, registry: ClassRegistry):
+
+    if config.interface_bases:
+        for base in config.interface_bases:
+            registry.register_import(base)
+
+        return [
+            ast.Name(id=base.split(".")[-1], ctx=ast.Load())
+            for base in config.interface_bases
+        ]
+    else:
+        for base in config.object_bases:
+            registry.register_import(base)
+
+        return [
+            ast.Name(id=base.split(".")[-1], ctx=ast.Load())
+            for base in config.object_bases
+        ]
